(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    167792,       2925]
NotebookOptionsPosition[    167998,       2912]
NotebookOutlinePosition[    168687,       2936]
CellTagsIndexPosition[    168644,       2933]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Beam Deflection\n",
 StyleBox["Qingchang Liu, Baoxing Xu \nUniversity of Virginia, 2018-04-30",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "1f0b3856-036c-4559-ac86-a359a58bd3e2"],

Cell["\<\
The module below shows how to determine the deflection of a beam. Two types \
of beam with two types of cross sections are available. As an intermediate \
step, the internal force diagram is also provided for the final determination \
of the deflection. \
\>", "Text",
 ExpressionUUID -> "50edfe98-c88f-49cd-b9d2-e658b33bf322"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dirf$$ = 120, $CellContext`dirm$$ = 
    1, $CellContext`length$$ = 0.5, $CellContext`mf$$ = 
    0.5, $CellContext`mm$$ = 0.25, $CellContext`opa1$$ = 
    0, $CellContext`opa2$$ = 1, $CellContext`pf$$ = 0.4, $CellContext`pm$$ = 
    0.6, $CellContext`reac$$ = 0, $CellContext`ri$$ = 
    0.09, $CellContext`ro$$ = 0.1, $CellContext`sectiontype$$ = 
    1, $CellContext`step2$$ = 0, $CellContext`step3$$ = 
    0, $CellContext`width$$ = 0.15, $CellContext`Y$$ = 50, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"\:65e0\:6807\:9898\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Coordinates visibility", 
         Spacer[55]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[$CellContext`opa2$$], 1, 
       Row[{"Types of Beam", 
         Spacer[85]}]}, {
      1 -> "\!\(\*\nStyleBox[\"Cantilever\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"Simply\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Supported\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`pf$$], 0.4, 
       Row[{"Position of force [m]", 
         Spacer[100]}]}, 0, 1}, {{
       Hold[$CellContext`mf$$], 0.5, 
       Row[{
        "\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[79]}]}, 0, 0.5}, {{
       Hold[$CellContext`dirf$$], 120, 
       Row[{
        "\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Degree]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[98]}]}, 0, 360}, {{
       Hold[$CellContext`pm$$], 0.6, 
       Row[{
        "\!\(\*\nStyleBox[\"Position\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[83]}]}, 0, 1}, {{
       Hold[$CellContext`mm$$], 0.25, 
       Row[{
        "\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[48]}]}, 0, 0.5}, {{
       Hold[$CellContext`dirm$$], 1, 
       Row[{
        "\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[93]}]}, {1 -> "CCW", 0 -> "CW"}}, {{
       Hold[$CellContext`reac$$], 0, 
       Row[{"Reactive Force & Moment", 
         Spacer[66.5]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`step2$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\
\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"II\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Internal\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"force\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"diagrams\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"of\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\n\
FontWeight->\"Bold\"]\)", 
         Spacer[20]}]}, {
      1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`step3$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\
\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"III\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Deflection\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"of\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\n\
FontWeight->\"Bold\"]\)", 
         Spacer[92]}]}, {
      1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`sectiontype$$], 1, 
       Row[{"Cross-section type", 
         Spacer[26.5]}]}, {1 -> "1", 2 -> "2"}}, {{
       Hold[$CellContext`width$$], 0.15, 
       Row[{"Height (h) [m]", 
         Spacer[104]}]}, 0.1, 0.2}, {{
       Hold[$CellContext`length$$], 0.5, 
       Row[{"Height/Width (h/b)", 
         Spacer[104]}]}, 0.1, 1}, {{
       Hold[$CellContext`ro$$], 0.1, 
       Row[{"Outer radius (\!\(\*SubscriptBox[\(r\), \(o\)]\)) [m]", 
         Spacer[85]}]}, 0.01, 0.5}, {{
       Hold[$CellContext`ri$$], 0.09, 
       Row[{"Inner radius (\!\(\*SubscriptBox[\(r\), \(i\)]\))[m]", 
         Spacer[85]}]}, 0, 
      Dynamic[0.99 $CellContext`ro$$]}, {{
       Hold[$CellContext`Y$$], 50, 
       Row[{"Young's Modulus of Beam[MPa]", 
         Spacer[31]}]}, 15, 100}, {
      Hold[
       Item[
        Column[{
          Grid[{{
             Manipulate`Place[1]}, {
             
             Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"I\",\nFontWeight->\
\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"External\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"loadings\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"and\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"reactive\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"forces\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"on\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\nFontWeight->\"Bold\"]\)", 
               Spacer[65]}]}, {
             Column[{
               Row[{
                 Manipulate`Place[2]}], 
               Row[{
                 Manipulate`Place[3]}], 
               Row[{
                 Manipulate`Place[4]}], 
               Row[{
                 Manipulate`Place[5]}], 
               Row[{
                 Manipulate`Place[6]}], 
               Row[{
                 Manipulate`Place[7]}], 
               Row[{
                 Manipulate`Place[8]}], 
               Row[{
                 Manipulate`Place[9]}], 
               Row[{
                 Dynamic[
                  If[$CellContext`reac$$ == 1, $CellContext`temp1, 
                   Invisible[$CellContext`temp]]]}]}]}, {
             Manipulate`Place[10]}, {
             Manipulate`Place[11]}, {
             Dynamic[$CellContext`im1, SynchronousUpdating -> False]}, {
             Manipulate`Place[12]}, {
             PaneSelector[{1 -> Column[{
                  Manipulate`Place[13], 
                  Manipulate`Place[14]}], 2 -> Column[{
                  Manipulate`Place[15], 
                  Manipulate`Place[16]}]}, 
              Dynamic[$CellContext`sectiontype$$]]}, {
             Manipulate`Place[17]}}, Alignment -> Left, 
           Spacings -> {Automatic, 1.5}]}]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    740., {267., 273.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`opa1$51517$$ = 
    False, $CellContext`opa2$51518$$ = False, $CellContext`pf$51519$$ = 
    0, $CellContext`mf$51520$$ = 0, $CellContext`dirf$51521$$ = 
    0, $CellContext`pm$51522$$ = 0, $CellContext`mm$51523$$ = 
    0, $CellContext`dirm$51524$$ = False, $CellContext`reac$51525$$ = 
    False, $CellContext`width$51526$$ = 0, $CellContext`length$51527$$ = 
    0, $CellContext`ro$51528$$ = 0, $CellContext`ri$51529$$ = 
    0, $CellContext`Y$51530$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`dirf$$ = 120, $CellContext`dirm$$ = 
        1, $CellContext`length$$ = 0.5, $CellContext`mf$$ = 
        0.5, $CellContext`mm$$ = 0.25, $CellContext`opa1$$ = 
        0, $CellContext`opa2$$ = 1, $CellContext`pf$$ = 
        0.4, $CellContext`pm$$ = 0.6, $CellContext`reac$$ = 
        0, $CellContext`ri$$ = 0.09, $CellContext`ro$$ = 
        0.1, $CellContext`sectiontype$$ = 1, $CellContext`step2$$ = 
        0, $CellContext`step3$$ = 0, $CellContext`width$$ = 
        0.15, $CellContext`Y$$ = 50}, "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$51517$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$51518$$, False], 
        Hold[$CellContext`pf$$, $CellContext`pf$51519$$, 0], 
        Hold[$CellContext`mf$$, $CellContext`mf$51520$$, 0], 
        Hold[$CellContext`dirf$$, $CellContext`dirf$51521$$, 0], 
        Hold[$CellContext`pm$$, $CellContext`pm$51522$$, 0], 
        Hold[$CellContext`mm$$, $CellContext`mm$51523$$, 0], 
        Hold[$CellContext`dirm$$, $CellContext`dirm$51524$$, False], 
        Hold[$CellContext`reac$$, $CellContext`reac$51525$$, False], 
        Hold[$CellContext`width$$, $CellContext`width$51526$$, 0], 
        Hold[$CellContext`length$$, $CellContext`length$51527$$, 0], 
        Hold[$CellContext`ro$$, $CellContext`ro$51528$$, 0], 
        Hold[$CellContext`ri$$, $CellContext`ri$51529$$, 0], 
        Hold[$CellContext`Y$$, $CellContext`Y$51530$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`alfa$, $CellContext`L$, \
$CellContext`W$, 
         Null$, $CellContext`pa$, $CellContext`pb$, $CellContext`pau$, \
$CellContext`pad$, $CellContext`pina1$, $CellContext`pina2$, \
$CellContext`pina3$, $CellContext`pinal$, $CellContext`pinar$, \
$CellContext`robr$, $CellContext`robc$, $CellContext`rolbr$, \
$CellContext`rolbl$, $CellContext`fe$, $CellContext`fi$, $CellContext`fx$, \
$CellContext`fy$, $CellContext`mp$, $CellContext`sitaie$, \
$CellContext`sitai$, $CellContext`sitae$, $CellContext`rm$, $CellContext`mi$, \
$CellContext`me$, $CellContext`cAx$, $CellContext`cAy$, $CellContext`cFm$, \
$CellContext`cMm$, $CellContext`cMA$, $CellContext`rMA$, \
$CellContext`sitaMA$, $CellContext`sitaMAi$, $CellContext`sitaMAe$, \
$CellContext`mAi$, $CellContext`mAe$, $CellContext`sAx$, $CellContext`sAy$, \
$CellContext`sBy$, $CellContext`cifx$, $CellContext`cify$, \
$CellContext`cifMs$, $CellContext`cimMs$, $CellContext`ciMs$, \
$CellContext`rMs$, $CellContext`csitaiMs$, $CellContext`csitaiMsi$, \
$CellContext`csitaiMse$, $CellContext`csitaiMsid$, $CellContext`csitaiMsed$, \
$CellContext`cmsi$, $CellContext`cmse$, $CellContext`cmsid$, \
$CellContext`cmsed$, $CellContext`sifx$, $CellContext`sify$, \
$CellContext`siMs$, $CellContext`ssitaiMs$, $CellContext`ssitaiMsi$, \
$CellContext`ssitaiMse$, $CellContext`ssitaiMsid$, $CellContext`ssitaiMsed$, \
$CellContext`smsi$, $CellContext`smse$, $CellContext`smsid$, \
$CellContext`smsed$, $CellContext`sopa1$, $CellContext`sopa2$, \
$CellContext`sopa3$, $CellContext`psu$, $CellContext`psd$, \
$CellContext`cxfx$, $CellContext`cxfy$, $CellContext`cxMs$, \
$CellContext`sxfx$, $CellContext`sxfy$, $CellContext`sxMs$, \
$CellContext`normal$, $CellContext`shear$, $CellContext`moment$, \
$CellContext`x$, $CellContext`csru$, $CellContext`csrd$, $CellContext`csr$, \
$CellContext`ssru$, $CellContext`ssrd$, $CellContext`ssr$, \
$CellContext`cmru$, $CellContext`cmrd$, $CellContext`cmr$, \
$CellContext`smru$, $CellContext`smrd$, $CellContext`smr$, \
$CellContext`dwf0$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dwf10$, $CellContext`dwf11$, \
$CellContext`dwf12$, $CellContext`dwf13$, $CellContext`dwf14$, \
$CellContext`dwf15$, $CellContext`dwf16$, $CellContext`dwf17$}, \
$CellContext`im1 = Image[
           Image[CompressedData["
1:eJzsvQl4HNWZ91uSNwyEYQkBAiFMEsKWBbJ+zJchmTtZbp6buTMk+WbJJIFM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            "], "Byte", ColorSpace -> "RGB", ImageResolution -> {150, 150}, 
            Interleaving -> True], ImageSize -> 200]; $CellContext`size$ = 
         1; $CellContext`YM = $CellContext`Y$$ 
          10^6; $CellContext`alfa$ = ($CellContext`dirf$$/180) Pi; 
        If[$CellContext`dirm$$ == 
          1, $CellContext`cMm$ = $CellContext`mm$$, $CellContext`cMm$ = \
-$CellContext`mm$$]; $CellContext`L$ = 1; $CellContext`W$ = 
         0.1 $CellContext`L$; $CellContext`pa$ = {0, 
          0}; $CellContext`pb$ = {$CellContext`L$, 
           0}; $CellContext`pau$ = $CellContext`pa$ + {
           0, $CellContext`W$}; $CellContext`pad$ = $CellContext`pa$ + {
           0, -$CellContext`W$}; $CellContext`pina1$ = $CellContext`pa$; \
$CellContext`pina2$ = $CellContext`pa$ + {(-$CellContext`W$)/
            1.5, (-$CellContext`W$)/
            1.1}; $CellContext`pina3$ = $CellContext`pa$ + {$CellContext`W$/
            1.5, (-$CellContext`W$)/
            1.1}; $CellContext`pinal$ = $CellContext`pina2$ + \
{(-$CellContext`W$)/4, 
            0}; $CellContext`pinar$ = $CellContext`pina3$ + {$CellContext`W$/
            4, 0}; $CellContext`robr$ = (Abs[
             Part[$CellContext`pinal$, 2]] - $CellContext`W$/2)/
          2; $CellContext`robc$ = {$CellContext`L$, -$CellContext`robr$ - \
$CellContext`W$/2} + {(-$CellContext`robr$)/2, 
            0}; $CellContext`rolbr$ = $CellContext`pinar$ + {$CellContext`L$, 
            0} + {(-$CellContext`robr$)/2, 
            0}; $CellContext`rolbl$ = $CellContext`pinal$ + {$CellContext`L$, 
            0} + {(-$CellContext`robr$)/2, 
            0}; $CellContext`fe$ = {$CellContext`pf$$ $CellContext`L$, 
           0}; $CellContext`fi$ = {$CellContext`mf$$ 
            Cos[$CellContext`alfa$], $CellContext`mf$$ 
            Sin[$CellContext`alfa$]} + $CellContext`fe$; $CellContext`fx$ = {
          Part[$CellContext`fe$, 1] - Part[$CellContext`fi$, 1], 
           0}; $CellContext`fy$ = {
          0, Part[$CellContext`fe$, 2] - 
           Part[$CellContext`fi$, 2]}; $CellContext`mp$ = {$CellContext`pm$$, 
           0}; $CellContext`sitaie$ = ($CellContext`cMm$ 1.8) 
          Pi; $CellContext`sitai$ = (-$CellContext`sitaie$)/
          2; $CellContext`sitae$ = $CellContext`sitaie$/2; $CellContext`rm$ = 
         1.2 $CellContext`W$; $CellContext`mi$ = {$CellContext`rm$ 
            Cos[$CellContext`sitae$ - $CellContext`sitaie$ 
              0.1], $CellContext`rm$ 
            Sin[$CellContext`sitae$ - $CellContext`sitaie$ 
              0.1]} + $CellContext`mp$; $CellContext`me$ = {$CellContext`rm$ 
            Cos[$CellContext`sitae$], $CellContext`rm$ 
            Sin[$CellContext`sitae$]} + $CellContext`mp$; 
        If[$CellContext`sectiontype$$ == 
          1, $CellContext`Inertia = \
($CellContext`width$$/$CellContext`length$$) ($CellContext`width$$^3/
            12), $CellContext`Inertia = (Pi/
            4) ($CellContext`ro$$^4 - $CellContext`ri$$^4)]; \
$CellContext`cAx$ = -$CellContext`fx$; $CellContext`cAy$ = -$CellContext`fy$; \
$CellContext`cFm$ = 
         Part[$CellContext`fy$, 
            2] $CellContext`pf$$; $CellContext`cMA$ = $CellContext`cFm$ + \
$CellContext`cMm$; $CellContext`rMA$ = $CellContext`rm$; $CellContext`sitaMA$ = \
($CellContext`cMA$ 1.8) Pi; $CellContext`sitaMAi$ = 
         Pi + $CellContext`sitaMA$/2; $CellContext`sitaMAe$ = 
         Pi - $CellContext`sitaMA$/
          2; $CellContext`mAi$ = {$CellContext`rMA$ 
            Cos[$CellContext`sitaMAe$ + ($CellContext`sitaMAe$ - \
$CellContext`sitaMAi$) 0.1], $CellContext`rMA$ 
            Sin[$CellContext`sitaMAe$ + ($CellContext`sitaMAe$ - \
$CellContext`sitaMAi$) 
               0.1]} + $CellContext`pa$; $CellContext`mAe$ = \
{$CellContext`rMA$ Cos[$CellContext`sitaMAe$], $CellContext`rMA$ 
            Sin[$CellContext`sitaMAe$]} + $CellContext`pa$; $CellContext`sAx$ = \
-$CellContext`fx$; $CellContext`sBy$ = {
          0, -$CellContext`cMm$ - 
           Part[$CellContext`fy$, 
             2] ($CellContext`pf$$/$CellContext`L$)}; $CellContext`sAy$ = \
-$CellContext`sBy$ - $CellContext`fy$; $CellContext`cxfx$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`cAx$, 1] - 
          UnitStep[$CellContext`x$ - $CellContext`pf$$] 
          Part[$CellContext`fx$, 1]; $CellContext`cxfy$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`cAy$, 2] - 
          Part[$CellContext`fy$, 2] 
          UnitStep[$CellContext`x$ - $CellContext`pf$$]; $CellContext`cxMs$[
           Pattern[$CellContext`x$, 
            Blank[]]] := $CellContext`cMA$ - 
          UnitStep[$CellContext`x$ - $CellContext`pm$$] $CellContext`cMm$ + 
          Part[$CellContext`cAy$, 2] $CellContext`x$ + (
            Part[$CellContext`fy$, 2] ($CellContext`x$ - $CellContext`pf$$)) 
           UnitStep[$CellContext`x$ - $CellContext`pf$$]; $CellContext`sxfx$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`sAx$, 1] - 
          UnitStep[$CellContext`x$ - $CellContext`pf$$] 
          Part[$CellContext`fx$, 1]; $CellContext`sxfy$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`sAy$, 2] - 
          UnitStep[$CellContext`x$ - $CellContext`pf$$] 
          Part[$CellContext`fy$, 2]; $CellContext`sxMs$[
           Pattern[$CellContext`x$, 
            Blank[]]] := 
         Part[$CellContext`sAy$, 2] $CellContext`x$ + (
            Part[$CellContext`fy$, 2] ($CellContext`x$ - $CellContext`pf$$)) 
           UnitStep[$CellContext`x$ - $CellContext`pf$$] - 
          UnitStep[$CellContext`x$ - $CellContext`pm$$] $CellContext`cMm$; \
$CellContext`csr$ = Norm[$CellContext`fy$]; $CellContext`ssr$ = 
         Norm[$CellContext`sAy$] + Norm[$CellContext`fy$]; 
        If[Abs[$CellContext`cMA$] > Abs[$CellContext`cMm$], $CellContext`cmr$ = 
          Abs[$CellContext`cMA$], $CellContext`cmr$ = Abs[$CellContext`cMm$]]; 
        If[Sign[$CellContext`cMm$] Sign[
             Part[$CellContext`sBy$, 2]] >= 0, $CellContext`smr$ = 
          Abs[$CellContext`cMm$] + 
           Abs[Part[$CellContext`sBy$, 
               2] ($CellContext`L$ - $CellContext`pf$$)], $CellContext`smr$ = 
          Abs[Abs[$CellContext`cMm$] - Abs[
            Part[$CellContext`sBy$, 
               2] ($CellContext`L$ - $CellContext`pm$$)]]]; 
        If[$CellContext`opa2$$ == 1, $CellContext`normal$ = Labeled[
            Plot[
             $CellContext`cxfx$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"N\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) Norm[$CellContext`fx$], 1.1 
               Norm[$CellContext`fx$]}, ImageMargins -> 5, ImageSize -> 350, 
             AspectRatio -> 0.35, AxesOrigin -> {0, 0}, Filling -> Axis, 
             FillingStyle -> Lighter[Red, 0.8]], 
            Text[
             Style["Normal Force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}], $CellContext`normal$ = Labeled[
            Plot[
             $CellContext`sxfx$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"N\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) Norm[$CellContext`fx$], 1.1 
               Norm[$CellContext`fx$]}, ImageMargins -> 5, ImageSize -> 350, 
             AspectRatio -> 0.35, AxesOrigin -> {0, 0}, Filling -> Axis, 
             FillingStyle -> Lighter[Red, 0.8]], 
            Text[
             Style["Normal Force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; $CellContext`datashearsimp = 
         Table[{$CellContext`ps, $CellContext`i}, {$CellContext`i, \
-$CellContext`ssr$, $CellContext`ssr$, $CellContext`ssr$/10}]; 
        If[$CellContext`opa2$$ == 1, $CellContext`shear$ = Labeled[
            
            Plot[-$CellContext`cxfy$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"V\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) $CellContext`csr$, 1.1 $CellContext`csr$}, 
             ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Green, 0.8]], 
            Text[
             Style["Shear force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}], $CellContext`shear$ = Labeled[
            
            Plot[-$CellContext`sxfy$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               
               "\!\(\*\nStyleBox[\"V\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) $CellContext`ssr$, 1.1 $CellContext`ssr$}, 
             ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Green, 0.8]], 
            Text[
             Style["Shear Force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; 
        If[$CellContext`opa2$$ == 1, $CellContext`moment$ = Labeled[
            Plot[
             $CellContext`cxMs$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"M\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\
\[CenterDot]\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\"m\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)"}, PlotRange -> {(-1.1) $CellContext`cmr$, 1.1 $CellContext`cmr$}, 
             ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Blue, 0.8]], 
            Text[
             Style["Bending Moment", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}], $CellContext`moment$ = Labeled[
            Plot[
             $CellContext`sxMs$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"M\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\
\[CenterDot]\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\"m\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)"}, ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Blue, 0.8]], 
            Text[
             Style["Bending Moment", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; 
        If[$CellContext`step1 == 1, $CellContext`sopa1$ = 
          1, $CellContext`sopa1$ = 0]; 
        If[$CellContext`step2$$ == 1, $CellContext`sopa2$ = 
          1, $CellContext`sopa2$ = 0]; 
        If[$CellContext`step2$$ == 1, $CellContext`sopa3$ = 
          1, $CellContext`sopa3$ = 
          0]; $CellContext`psu$ = {$CellContext`ps, 0} + {
           0, 2 $CellContext`W$}; $CellContext`psd$ = {$CellContext`ps, 0} + {
           0, (-2) $CellContext`W$}; 
        If[$CellContext`opa2$$ == 1, $CellContext`temp1 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"A\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\
\!\(\*\nStyleBox[\"  \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[-$CellContext`cMA$, {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 1.]]\)", 
             NumberForm[
              Part[$CellContext`cAx$, 1], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`cAy$, 2], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}]]; 
        If[$CellContext`opa2$$ == 0, $CellContext`temp1 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`sAx$, 1], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`sAy$, 2], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"B\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`sBy$, 2], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}]]; 
        If[$CellContext`step2$$ == 0, $CellContext`int = 0]; 
        If[$CellContext`step2$$ == 1, $CellContext`step1 = 1]; 
        If[$CellContext`step2$$ == 1, $CellContext`int = 1]; 
        If[$CellContext`step2$$ == 1, $CellContext`step1 = 1]; 
        If[$CellContext`step2$$ == 1, $CellContext`step2$$ = 1]; Row[{
           Item[$CellContext`dwf0$ = {
               Opacity[$CellContext`opa1$$], 
               Dashing[{}], 
               Thickness[0.001], 
               Arrowheads[0.02], 
               
               Arrow[{{-$CellContext`size$, 0}, {
                 1.15 $CellContext`size$, 0}}], 
               
               Arrow[{{0, (-0.45) $CellContext`size$}, {
                 0, 0.45 $CellContext`size$}}], 
               Text[
               "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {1.2 $CellContext`size$, 0}], 
               Text[
               "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
                 0.45 $CellContext`size$}]}; $CellContext`dwf1$ = {
               Opacity[0.5], Blue, 
               
               Rectangle[{
                0, (-0.5) $CellContext`W$}, {$CellContext`L$, 
                 0.5 $CellContext`W$}]}; $CellContext`dwf2$ = {
               Opacity[$CellContext`opa2$$ (1 - $CellContext`reac$$)], 
               Line[{$CellContext`pau$, $CellContext`pad$}], 
               Line[
                
                Table[{{
                  0, $CellContext`W$ - $CellContext`W$ $CellContext`k}, \
{(-$CellContext`W$)/
                   4, $CellContext`W$ - $CellContext`W$ ($CellContext`k + 
                    0.25)}}, {$CellContext`k, 0, 1.8, 
                  0.2}]]}; $CellContext`dwf3$ = {
               Opacity[(1 - $CellContext`opa2$$) (1 - $CellContext`reac$$)], 
               Darker[Green], 
               PointSize[0.02], 
               Point[$CellContext`pa$], 
               
               Triangle[{$CellContext`pina1$, $CellContext`pina2$, \
$CellContext`pina3$}], 
               Line[{$CellContext`pinal$, $CellContext`pinar$}], 
               Line[
                
                Table[{{
                  Part[$CellContext`pinal$, 
                    1] + $CellContext`W$ ($CellContext`k + 0.15), 
                   Part[$CellContext`pinal$, 2]}, {
                  Part[$CellContext`pinal$, 
                    1] + $CellContext`W$ $CellContext`k, 
                   Part[$CellContext`pinal$, 2] - $CellContext`W$/
                   4}}, {$CellContext`k, 0, 1.7, 0.15}]], 
               Circle[$CellContext`robc$, $CellContext`robr$], 
               Line[{$CellContext`rolbr$, $CellContext`rolbl$}], 
               Line[
                
                Table[{{
                  Part[$CellContext`rolbl$, 
                    1] + $CellContext`W$ ($CellContext`k + 0.15), 
                   Part[$CellContext`rolbl$, 2]}, {
                  Part[$CellContext`rolbl$, 
                    1] + $CellContext`W$ $CellContext`k, 
                   Part[$CellContext`rolbl$, 2] - $CellContext`W$/
                   4}}, {$CellContext`k, 0, 1.7, 0.15}]]}; $CellContext`dwf4$ = {
               Opacity[1], 
               Thickness[0.005], Dashed, 
               Thickness[0.004], 
               
               Line[{{$CellContext`W$/4, 
                  0}, {$CellContext`L$ - $CellContext`W$/4, 0}}], Black, 
               Text[
               "A", $CellContext`pa$ + {
                 0.3 $CellContext`W$, $CellContext`W$}], 
               Text[
               "B", $CellContext`pb$ + {(-0.3) $CellContext`W$, \
$CellContext`W$}]}; $CellContext`dwf5$ = {
               Opacity[1 (1 - $CellContext`reac$$)], Black, 
               Thickness[0.005], 
               PointSize[0.01], 
               Point[$CellContext`fe$], 
               Arrowheads[0.03], 
               Arrow[{$CellContext`fi$, $CellContext`fe$}], 
               If[Norm[$CellContext`fe$ - $CellContext`fi$] > 0, 
                Text[
                "F", $CellContext`fi$ + {0.05, 0.05}]]}; $CellContext`dwf6$ = {
               Opacity[1], Black, 
               Thickness[0.005], 
               PointSize[0.01], 
               Point[$CellContext`mp$], 
               Arrowheads[0.03], 
               Arrow[{$CellContext`mi$, $CellContext`me$}], 
               
               Circle[$CellContext`mp$, $CellContext`rm$, \
{$CellContext`sitai$, $CellContext`sitae$}], 
               If[$CellContext`mm$$ > 0, 
                If[$CellContext`dirm$$ > 0, 
                 Text[
                 "M", $CellContext`me$ + {
                   0.5 $CellContext`W$, 0.5 $CellContext`W$}], 
                 Text[
                 "M", $CellContext`me$ + {
                   0.5 $CellContext`W$, (-0.5) $CellContext`W$}]]]}; \
$CellContext`dwf7$ = {
               Opacity[$CellContext`reac$$ $CellContext`opa2$$], Red, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`cAx$, \
$CellContext`pa$}], 
                
                Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`cAx$}]], 
               If[Norm[$CellContext`fx$] > 0, 
                If[Part[$CellContext`fx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`cAx$ + {0, $CellContext`W$/1.5}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`cAx$ + {0, $CellContext`W$/1.5}]]], 
               
               Arrow[{$CellContext`pa$ - $CellContext`cAy$, \
$CellContext`pa$}], 
               If[Norm[$CellContext`cAy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`cAy$ + {$CellContext`W$/1.5, 0}]], Blue, 
               If[Part[$CellContext`fx$, 1] > 0, 
                
                Arrow[{$CellContext`mAe$ + $CellContext`cAx$, \
$CellContext`mAi$ + $CellContext`cAx$}], 
                
                Arrow[{$CellContext`mAe$ - $CellContext`cAx$, \
$CellContext`mAi$ - $CellContext`cAx$}]], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Circle[$CellContext`pa$ - $CellContext`cAx$, \
$CellContext`rMA$, {$CellContext`sitaMAi$, $CellContext`sitaMAe$}], 
                
                Circle[$CellContext`pa$ + $CellContext`cAx$, \
$CellContext`rMA$, {$CellContext`sitaMAi$, $CellContext`sitaMAe$}]], 
               If[Part[$CellContext`fx$, 1] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mAe$ + \
$CellContext`cAx$ + 
                 Sign[$CellContext`cMA$] {$CellContext`W$/2, $CellContext`W$/
                    1.5}], 
                Text[
                "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mAe$ - \
$CellContext`cAx$ + 
                 Sign[$CellContext`cMA$] {$CellContext`W$/2, $CellContext`W$/
                    1.5}]], Black, 
               Arrow[{$CellContext`fe$ - $CellContext`fx$, $CellContext`fe$}], 
               If[Norm[$CellContext`fx$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fe$ - \
$CellContext`fx$ + {0, $CellContext`W$/1.5}]], 
               Arrow[{$CellContext`fe$ - $CellContext`fy$, $CellContext`fe$}], 
               If[Norm[$CellContext`fy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fe$ - \
$CellContext`fy$ + {$CellContext`W$/1.5, 0}]]}; $CellContext`dwf8$ = {
               Opacity[$CellContext`reac$$ (1 - $CellContext`opa2$$)], Red, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`sAx$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pa$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pa$ + $CellContext`sAx$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`fx$] > 0, 
                If[Part[$CellContext`fx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`sAx$ + {0, (-$CellContext`W$)/2} + {0, $CellContext`W$/1.5}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`sAx$ + {0, (-$CellContext`W$)/2} + {0, $CellContext`W$/1.5}]]], 
               If[Part[$CellContext`sAy$, 2] > 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`sAy$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pa$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pa$ + $CellContext`sAy$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`sAy$] > 0, 
                If[Part[$CellContext`sAy$, 2] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`sAy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ + \
$CellContext`sAy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}]]], 
               If[Part[$CellContext`sBy$, 2] > 0, 
                
                Arrow[{$CellContext`pb$ - $CellContext`sBy$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pb$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pb$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pb$ + $CellContext`sBy$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`sBy$] > 0, 
                If[Part[$CellContext`sBy$, 2] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pb$ - \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pb$ + \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}]]], 
               Black, 
               Arrow[{$CellContext`fe$ - $CellContext`fx$, $CellContext`fe$}], 
               If[Norm[$CellContext`fx$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fe$ - \
$CellContext`fx$ + {0, $CellContext`W$/1.5}]], 
               Arrow[{$CellContext`fe$ - $CellContext`fy$, $CellContext`fe$}], 
               If[Norm[$CellContext`fy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fe$ - \
$CellContext`fy$ + {$CellContext`W$/1.5, 0}]]}; $CellContext`dwf9$ = {
               Opacity[$CellContext`opa2$$ $CellContext`step3$$], 
               
               Line[{$CellContext`pau$ + {
                  0, -$CellContext`size$}, $CellContext`pad$ + {
                  0, -$CellContext`size$}}], 
               Line[
                
                Table[{{
                   0, $CellContext`W$ - $CellContext`W$ $CellContext`k} + {
                   0, -$CellContext`size$}, {(-$CellContext`W$)/
                    4, $CellContext`W$ - $CellContext`W$ ($CellContext`k + 
                    0.25)} + {0, -$CellContext`size$}}, {$CellContext`k, 0, 
                  1.8, 0.2}]], Black, Dashed, 
               Thickness[0.004], 
               
               Line[{{0, -$CellContext`size$}, {$CellContext`L$, \
-$CellContext`size$}}], 
               Text[
               "A", $CellContext`pa$ + {
                 0.3 $CellContext`W$, $CellContext`W$ - $CellContext`size$}], 
               Text[
               "B", $CellContext`pb$ + {(-0.3) $CellContext`W$, \
$CellContext`W$ - $CellContext`size$}]}; $CellContext`dwf10$ = {
               Opacity[(1 - $CellContext`opa2$$) $CellContext`step3$$], 
               Darker[Green], 
               PointSize[0.02], 
               Point[$CellContext`pa$ + {0, -$CellContext`size$}], 
               
               Triangle[{$CellContext`pina1$ + {
                  0, -$CellContext`size$}, $CellContext`pina2$ + {
                  0, -$CellContext`size$}, $CellContext`pina3$ + {
                  0, -$CellContext`size$}}], 
               
               Line[{$CellContext`pinal$ + {
                  0, -$CellContext`size$}, $CellContext`pinar$ + {
                  0, -$CellContext`size$}}], 
               Line[
                
                Table[{{
                   Part[$CellContext`pinal$, 
                    1] + $CellContext`W$ ($CellContext`k + 0.15), 
                    Part[$CellContext`pinal$, 2]} + {
                   0, -$CellContext`size$}, {
                   Part[$CellContext`pinal$, 
                    1] + $CellContext`W$ $CellContext`k, 
                    Part[$CellContext`pinal$, 2] - $CellContext`W$/4} + {
                   0, -$CellContext`size$}}, {$CellContext`k, 0, 1.7, 0.15}]], 
               
               Circle[$CellContext`robc$ + {
                 0, (-0.95) $CellContext`size$}, $CellContext`robr$], 
               
               Line[{$CellContext`rolbr$ + {
                  0, (-0.95) $CellContext`size$}, $CellContext`rolbl$ + {
                  0, (-0.95) $CellContext`size$}}], 
               Line[
                
                Table[{{
                   Part[$CellContext`rolbl$, 
                    1] + $CellContext`W$ ($CellContext`k + 0.15), 
                    Part[$CellContext`rolbl$, 2]} + {
                   0, (-0.95) $CellContext`size$}, {
                   Part[$CellContext`rolbl$, 
                    1] + $CellContext`W$ $CellContext`k, 
                    Part[$CellContext`rolbl$, 2] - $CellContext`W$/4} + {
                   0, (-0.95) $CellContext`size$}}, {$CellContext`k, 0, 1.7, 
                  0.15}]], Black, Dashed, 
               Thickness[0.004], 
               
               Line[{{0, -$CellContext`size$}, {$CellContext`L$, \
-$CellContext`size$}}], 
               Text[
               "A", $CellContext`pa$ + {
                 0.3 $CellContext`W$, $CellContext`W$ - $CellContext`size$}], 
               Text[
               "B", $CellContext`pb$ + {(-0.3) $CellContext`W$, \
$CellContext`W$ - $CellContext`size$}]}; $CellContext`dw1 = 
             Graphics[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$, $CellContext`dwf10$}, 
               PlotRange -> {{(-0.5) $CellContext`size$, 
                  1.5 $CellContext`size$}, {(-1.8) $CellContext`size$, 
                  0.8 $CellContext`size$}}, ImageSize -> 380, Frame -> 
               True]; $CellContext`dw2 = 
             ParametricPlot[{$CellContext`x$, (((
                    UnitStep[$CellContext`pf$$ - $CellContext`x$] 1000) 
                   Part[$CellContext`fy$, 2]) $CellContext`x$^2) ((((
                    3 $CellContext`pf$$ - $CellContext`x$)/
                    6)/$CellContext`YM)/$CellContext`Inertia) + (((
                    UnitStep[$CellContext`x$ - $CellContext`pf$$] 1000) 
                   Part[$CellContext`fy$, 2]) $CellContext`pf$$^2) ((((
                    3 $CellContext`x$ - $CellContext`pf$$)/
                    6)/$CellContext`YM)/$CellContext`Inertia) + ((
                   UnitStep[$CellContext`pm$$ - $CellContext`x$] 
                   1000) $CellContext`cMm$) ((($CellContext`x$^2/
                    2)/$CellContext`YM)/$CellContext`Inertia) + 
                UnitStep[$CellContext`x$ - $CellContext`pm$$] ((
                    1000 $CellContext`cMm$) ((($CellContext`pm$$^2/
                    2)/$CellContext`YM)/$CellContext`Inertia) + (
                    Sign[$CellContext`cMm$] ($CellContext`x$ - \
$CellContext`pm$$)) 
                   Tan[(1000 
                    Abs[$CellContext`cMm$]) \
(($CellContext`pm$$/$CellContext`YM)/$CellContext`Inertia)]) - \
$CellContext`size$}, {$CellContext`x$, 0, $CellContext`L$}, PlotStyle -> {Red, 
                 Opacity[1]}]; $CellContext`dw3 = 
             ParametricPlot[{$CellContext`x$, ((((
                    UnitStep[$CellContext`pf$$ - $CellContext`x$] 1000) 
                    Part[$CellContext`fy$, 
                    2]) ($CellContext`L$ - $CellContext`pf$$)) \
$CellContext`x$) ((((($CellContext`L$^2 - $CellContext`x$^2 - \
($CellContext`L$ - $CellContext`pf$$)^2)/
                    6)/$CellContext`L$)/$CellContext`YM)/$CellContext`Inertia)\
 + (((UnitStep[$CellContext`x$ - $CellContext`pf$$] 1000) 
                   Part[$CellContext`fy$, 
                    2]) ($CellContext`L$ - $CellContext`pf$$)) \
((((($CellContext`L$ (($CellContext`x$ - \
$CellContext`pf$$)^3/($CellContext`L$ - $CellContext`pf$$)) + \
($CellContext`L$^2 - ($CellContext`L$ - $CellContext`pf$$)^2) $CellContext`x$ - \
$CellContext`x$^3)/
                    6)/$CellContext`L$)/$CellContext`YM)/$CellContext`Inertia)\
 - (((UnitStep[$CellContext`pm$$ - $CellContext`x$] 
                   1000) $CellContext`cMm$) $CellContext`x$) ((((((
                    6 $CellContext`pm$$) $CellContext`L$ - 
                    3 $CellContext`pm$$^2 - 
                    2 $CellContext`L$^2 - $CellContext`x$^2)/
                    6)/$CellContext`L$)/$CellContext`YM)/$CellContext`Inertia)\
 + (((UnitStep[$CellContext`x$ - $CellContext`pm$$] 
                    1000) $CellContext`cMm$) ($CellContext`L$ - \
$CellContext`x$)) ((((((
                    6 ($CellContext`L$ - $CellContext`pm$$)) $CellContext`L$ - 
                    3 ($CellContext`L$ - $CellContext`pm$$)^2 - 
                    2 $CellContext`L$^2 - ($CellContext`L$ - \
$CellContext`x$)^2)/
                    6)/$CellContext`L$)/$CellContext`YM)/$CellContext`Inertia)\
 - $CellContext`size$}, {$CellContext`x$, 0, $CellContext`L$}, 
               PlotStyle -> {Red, 
                 Opacity[1]}]; If[$CellContext`step3$$ == 1, 
              Show[$CellContext`dw1, 
               
               If[$CellContext`opa2$$ == 
                1, $CellContext`dw2, $CellContext`dw3]], 
              Show[$CellContext`dw1]]], 
           Item[
            Column[{
              Grid[{{
                 PaneSelector[{
                   Item[$CellContext`normal$, ItemSize -> Full]}, 
                  Dynamic[$CellContext`step2$$]]}, {
                 PaneSelector[{
                   Item[$CellContext`shear$, ItemSize -> Full]}, 
                  Dynamic[$CellContext`step2$$]]}, {
                 PaneSelector[{
                   Item[$CellContext`moment$, ItemSize -> Full]}, 
                  Dynamic[$CellContext`step2$$]]}}, Alignment -> Left, 
               Spacings -> {Automatic, 2.1}]}], ControlPlacement -> Right]}]],
       "Specifications" :> {{{$CellContext`opa1$$, 0, 
          Row[{"Coordinates visibility", 
            Spacer[55]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`opa2$$, 1, 
          Row[{"Types of Beam", 
            Spacer[85]}]}, {
         1 -> "\!\(\*\nStyleBox[\"Cantilever\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"Simply\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Supported\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> 
         SetterBar, ControlPlacement -> 2}, {{$CellContext`pf$$, 0.4, 
          Row[{"Position of force [m]", 
            Spacer[100]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 3}, {{$CellContext`mf$$, 0.5, 
          
          Row[{"\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[79]}]}, 0, 0.5, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`dirf$$, 120, 
          
          Row[{"\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Degree]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[98]}]}, 0, 360, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`pm$$, 0.6, 
          
          Row[{"\!\(\*\nStyleBox[\"Position\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[83]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{$CellContext`mm$$, 0.25, 
          
          Row[{"\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[48]}]}, 0, 0.5, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 7}, {{$CellContext`dirm$$, 1, 
          
          Row[{"\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[93]}]}, {1 -> "CCW", 0 -> "CW"}, ControlType -> SetterBar, 
         ControlPlacement -> 8}, {{$CellContext`reac$$, 0, 
          Row[{"Reactive Force & Moment", 
            Spacer[66.5]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         SetterBar, ControlPlacement -> 9}, {{$CellContext`step2$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"II\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Internal\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"force\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"diagrams\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"of\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\n\
FontWeight->\"Bold\"]\)", 
            Spacer[20]}]}, {
         1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> SetterBar, 
         ControlPlacement -> 10}, {{$CellContext`step3$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"III\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Deflection\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"of\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\n\
FontWeight->\"Bold\"]\)", 
            Spacer[92]}]}, {
         1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> SetterBar, 
         ControlPlacement -> 11}, {{$CellContext`sectiontype$$, 1, 
          Row[{"Cross-section type", 
            Spacer[26.5]}]}, {1 -> "1", 2 -> "2"}, ControlType -> 
         RadioButtonBar, ControlPlacement -> 
         12}, {{$CellContext`width$$, 0.15, 
          Row[{"Height (h) [m]", 
            Spacer[104]}]}, 0.1, 0.2, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 13}, {{$CellContext`length$$, 0.5, 
          Row[{"Height/Width (h/b)", 
            Spacer[104]}]}, 0.1, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 14}, {{$CellContext`ro$$, 0.1, 
          Row[{"Outer radius (\!\(\*SubscriptBox[\(r\), \(o\)]\)) [m]", 
            Spacer[85]}]}, 0.01, 0.5, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 15}, {{$CellContext`ri$$, 0.09, 
          Row[{"Inner radius (\!\(\*SubscriptBox[\(r\), \(i\)]\))[m]", 
            Spacer[85]}]}, 0, 
         Dynamic[0.99 $CellContext`ro$$], ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 16}, {{$CellContext`Y$$, 50, 
          Row[{"Young's Modulus of Beam[MPa]", 
            Spacer[31]}]}, 15, 100, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 17}, 
        Item[
         Column[{
           Grid[{{
              Manipulate`Place[1]}, {
              
              Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"I\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"External\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"loadings\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"and\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"reactive\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"forces\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"on\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\nFontWeight->\"Bold\"]\)", 
                Spacer[65]}]}, {
              Column[{
                Row[{
                  Manipulate`Place[2]}], 
                Row[{
                  Manipulate`Place[3]}], 
                Row[{
                  Manipulate`Place[4]}], 
                Row[{
                  Manipulate`Place[5]}], 
                Row[{
                  Manipulate`Place[6]}], 
                Row[{
                  Manipulate`Place[7]}], 
                Row[{
                  Manipulate`Place[8]}], 
                Row[{
                  Manipulate`Place[9]}], 
                Row[{
                  Dynamic[
                   If[$CellContext`reac$$ == 1, $CellContext`temp1, 
                    Invisible[$CellContext`temp]]]}]}]}, {
              Manipulate`Place[10]}, {
              Manipulate`Place[11]}, {
              Dynamic[$CellContext`im1, SynchronousUpdating -> False]}, {
              Manipulate`Place[12]}, {
              PaneSelector[{1 -> Column[{
                   Manipulate`Place[13], 
                   Manipulate`Place[14]}], 2 -> Column[{
                   Manipulate`Place[15], 
                   Manipulate`Place[16]}]}, 
               Dynamic[$CellContext`sectiontype$$]]}, {
              Manipulate`Place[17]}}, Alignment -> Left, 
            Spacings -> {Automatic, 1.5}]}], ControlPlacement -> Left]}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{1163., {299., 305.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "38e966ba-a559-4778-9fef-74d79e1a8c04"]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 561}, 
  WindowMargins -> {{25, Automatic}, {Automatic, 31}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 252, 7, 155, "Title"],
Cell[1741, 44, 337, 6, 49, "Text"],
Cell[2081, 52, 165901, 2857, 621, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature twDq3aj8lW6eaAKbcTYsnKWr *)
